function [param,fitinfo] = MMAnalytic(tdata,ydata,startp,endp,fitinfo)
% 
%
%

% Select Starting parameters depending on automatic flags set
if fitinfo.flags.dt_a && fitinfo.flags.s0_a
    mStart  = [max(ydata(startp:endp)) fitinfo.km_a ...
        fitinfo.vm_a -tdata(startp)];

elseif fitinfo.flags.dt_a && ~fitinfo.flags.s0_a
    mStart  = [fitinfo.s0_a fitinfo.km_a fitinfo.vm_a...
        -tdata(startp)];

elseif ~fitinfo.flags.dt_a && fitinfo.flags.s0_a
    mStart  = [max(ydata(startp:endp)) fitinfo.km_a...
        fitinfo.vm_a fitinfo.dt_a];

elseif ~fitinfo.flags.dt_a && ~fitinfo.flags.s0_a 
    mStart  = [fitinfo.s0_a fitinfo.km_a fitinfo.vm_a...
        fitinfo.dt_a];
end

% Choose upper and lower boundaries
mLower  = [max(ydata(startp:endp))/2 0.1 0 -max(tdata)];
mUpper  = [max(ydata(startp:endp))*100 10^5 10^6 max(tdata)];

% Choose function according to leakage behaviour
if fitinfo.flags.expleak
    GolFun=@(m,t)(m(1)-m(2).*(1.4586887.*log(1.2.*(m(1)/m(2).*exp((m(1)-m(3).*...
    (t+m(4)))./m(2)))./log(2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./...
    log(1+2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2))))))-0.4586887.*...
    log(2.*(m(1)/m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./log(1+2.*(m(1)./m(2).*...
    exp((m(1)-m(3).*(t+m(4)))./m(2))))))).*exp(-m(5).*t);
    mStart = [mStart fitinfo.kl];
    mLower = [mLower 0];
    mUpper = [mUpper Inf];
elseif fitinfo.flags.linleak
    GolFun=@(m,t)m(1)-m(2).*(1.4586887.*log(1.2.*(m(1)/m(2).*exp((m(1)-m(3).*...
    (t+m(4)))./m(2)))./log(2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./...
    log(1+2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2))))))-0.4586887.*...
    log(2.*(m(1)/m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./log(1+2.*(m(1)./m(2).*...
    exp((m(1)-m(3).*(t+m(4)))./m(2))))))-t.*m(5);
    mStart = [mStart fitinfo.l];
    mLower = [mLower 0];
    mUpper = [mUpper Inf];
else
    GolFun=@(m,t)m(1)-m(2).*(1.4586887.*log(1.2.*(m(1)/m(2).*exp((m(1)-m(3).*...
    (t+m(4)))./m(2)))./log(2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./...
    log(1+2.4.*(m(1)./m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2))))))-0.4586887.*...
    log(2.*(m(1)/m(2).*exp((m(1)-m(3).*(t+m(4)))./m(2)))./log(1+2.*(m(1)./m(2).*...
    exp((m(1)-m(3).*(t+m(4)))./m(2))))));
end

% Define least-square algorithm settings
v_TolX=10^-10;
v_TolFun=10^-10;
v_MaxFunEvals=1000;
v_MaxIter=10000;

% Save fitting details into fitinfo
fitinfo.formula=func2str(GolFun);
fitinfo.start_param=['[',sprintf('%d,',mStart(1:end-1)),sprintf('%d]',mStart(end))];
fitinfo.lower_limit=['[',sprintf('%d,',mLower(1:end-1)),sprintf('%d]',mLower(end))];
fitinfo.upper_limit=['[',sprintf('%d,',mUpper(1:end-1)),sprintf('%d]',mUpper(end))];
fitinfo.TolX=v_TolX;
fitinfo.TolFun=v_TolFun;
fitinfo.MaxFunEvals=v_MaxFunEvals;
fitinfo.MaxIter=v_MaxIter;

% Boundle up fitting options
fitoptions=optimoptions('lsqcurvefit','Display','off','TolX',v_TolX,'TolFun',v_TolFun,...
         'MaxFunEvals',v_MaxFunEvals,'MaxIter',v_MaxIter,'Algorithm',fitinfo.fitmethod);
%fitoptions=optimset('Display','off','TolX',v_TolX,'TolFun',v_TolFun,...
%         'MaxFunEvals',v_MaxFunEvals,'MaxIter',v_MaxIter,...
%         'Algorithm',fitinfo.fitmethod);


% Start least-square fitting with lsqcurvefit with boundaries
% (trust-region-reflective) or without (MA-method)
if strcmp(fitinfo.fitmethod,'trust-region-reflective')
    [param,resnorm,~,exitflag,~] = lsqcurvefit(GolFun,mStart,...
        tdata(startp:endp),ydata(startp:endp),mLower,mUpper,fitoptions);
else
    [param,resnorm,~,exitflag,~] = lsqcurvefit(GolFun,mStart,...
        tdata(startp:endp),ydata(startp:endp),[],[],fitoptions);
end

% Save fitting parameter results and add residuals. Also save exitflag for
% further evaluation
fitinfo.flags.exitflag=exitflag;
if size(param,1)>1
    param=param';
end
param=[param,resnorm];

% Call afterfit for plotting
fitinfo=MMAfterfit(tdata,ydata,param,fitinfo);
                  
end

