function [ cPro ] = MMSimExpFit( m , tdata , varargin)
%GALCUGFIT Summary of this function goes here
%   m: cEnz cSub kEnzSub_ES kES_ProEnz kPro_Was
    
    cPro=0;
    cWas=0;
    cES=0;
    kLS=0;
    tStepSize=mean(diff(tdata));
    cResult=zeros(length(tdata),5); 
    
    if nargin == 3
        cEnz=varargin{1};
        cSub=m(1);
        kF=m(2);
        kR=m(3);
        kCat=m(4);
        deltat=m(5);
        kL=m(6);
    else
        if nargin > 3
           error('Too many input arguments'); 
        end
        cEnz=m(1);
        cSub=m(2);
        kF=m(3);
        kR=m(4);
        kCat=m(5);
        deltat=m(6);
        kL=m(7);
    end

    offset=0;
    cWorking=[cEnz,cPro,cSub,cWas,cES];
    if deltat<0
        offset=ceil(-deltat/tStepSize);
        cWorking=galcugmodel(deal(cWorking),kF,kR,kCat,kL,kLS,tStepSize*offset+deltat);
    else
        cWorking=galcugmodel(deal(cWorking),kF,kR,kCat,kL,kLS,deltat);
    end
    
    
    for i=1:length(tdata)
        
        if i>offset
            cResult(i,:)=cWorking;
            cWorking=galcugmodel(deal(cWorking),kF,kR,kCat,kL,kLS,tStepSize);
        else
            cResult(i,:)=[cEnz,cPro,cSub,cWas,cES];
        end
    end
    %set(0,'Recursionlimit',500)
    cPro=cResult(:,2);
    return

end

function [cOutput] = galcugmodel(cInput,kF,kR,kCat,kL,kLS,tStepSize)
%   [cEnzOut,cProOut,cSubOut,cWasOut,cESOut] = galcugmodel(cInput,kEnzSub_ES,kES_ProEnz,kPro_Was,kSub_Was,tStepSize)
%   For cInput use following order:
%       cEnz, cPro, cSub, cWas, cES
%
    [cEnzIn,cProIn,cSubIn,cWasIn,cESIn]=deal(cInput(1),cInput(2),cInput(3),cInput(4),cInput(5));
    
    cEnzOut=cEnzIn + tStepSize*(-kF   * cEnzIn * cSubIn +kCat * cESIn  +kR * cESIn);
    cSubOut=cSubIn + tStepSize*(-kF   * cEnzIn * cSubIn -kLS  * cSubIn +kR * cESIn);
    cProOut=cProIn + tStepSize*(+kCat * cESIn           -kL   * cProIn            );
    cESOut =cESIn  + tStepSize*(+kF   * cEnzIn * cSubIn -kCat * cESIn  -kR * cESIn);
    cWasOut=cWasIn + tStepSize*(+kL   * cProIn          +kLS  * cSubIn            );
    
    limit=2;
    offset=mean([cEnzIn,cProIn,cSubIn,cWasIn,cESIn])/100;
    
    if cEnzOut<cEnzIn/limit || cSubOut<cSubIn/limit || cProOut<cProIn/limit || cWasOut<cWasIn/limit || cESOut<cESIn/limit ...
            || cEnzOut>(cEnzIn+offset)*limit || cSubOut>(cSubIn+offset)*limit || cProOut>(cProIn+offset)*limit || cWasOut>(cWasIn+offset)*limit || cESOut>(cESIn+offset)*limit
        %if cSubIn-(cESOut+cSubOut+cProOut)~=0
        %    fprintf('Y')
        %end
        cOutputRecursive=galcugmodel(cInput,kF,kR,kCat,kL,kLS,tStepSize/4);
        cOutputRecursive=galcugmodel(cOutputRecursive,kF,kR,kCat,kL,kLS,tStepSize/4);
        cOutputRecursive=galcugmodel(cOutputRecursive,kF,kR,kCat,kL,kLS,tStepSize/4);
        cOutput=galcugmodel(cOutputRecursive,kF,kR,kCat,kL,kLS,tStepSize/4);
    else 
        cOutput=[cEnzOut, cProOut,cSubOut,cWasOut,cESOut];
    end
    
    return
end