function [ cPro ] = MMSimNolFit( m , tdata , varargin)
%GALCUGFIT Summary of this function goes here
%   m: cEnz cSub kEnzSub_ES kES_ProEnz kPro_Was
    
cPro=0;
cES=0;
tStepSize=mean(diff(tdata));
cResult=zeros(length(tdata),4); 

if nargin == 3
    cEnz=varargin{1};
    if isnan(cEnz)
       error('No enzyme concentration defined'); 
    end
    cSub=m(1);
    kF=m(2);
    kR=m(3);
    kCat=m(4);
    deltat=m(5);
else
    if nargin > 3
       error('Too many input arguments'); 
    end
    cEnz=m(1);
    cSub=m(2);
    kF=m(3);
    kR=m(4);
    kCat=m(5);
    deltat=m(6);
end
offset=0;
cWorking=[cEnz,cPro,cSub,cES];
if deltat<0
    cWorking=lacmodel(deal(cWorking),kF,kR,kCat,-deltat,0);
else
    offset=ceil(deltat/tStepSize);
    cWorking=lacmodel(deal(cWorking),kF,kR,kCat,tStepSize*offset-deltat,0);
end


for i=1:length(tdata)

    if i>offset
        cResult(i,:)=cWorking;
        cWorking=lacmodel(deal(cWorking),kF,kR,kCat,tStepSize,0);
    else
        cResult(i,:)=[cEnz,cPro,cSub,cES];
    end
end

cPro=cResult(:,2);
return

end

function [cOutput] = lacmodel(cInput,kF,kR,kCat,tStepSize,recursiveNumber)
%   For cInput use following order:
%       cEnz, cPro, cSub, cWas, cES
%

exitConstant = 1.2; % Has to be larger than 1, suggested value 2
exitRecNumber = 25;

recursiveNumber=recursiveNumber+1;
[cEnzIn,cProIn,cSubIn,cESIn]=deal(cInput(1),cInput(2),cInput(3),cInput(4));

cEnzOut=cEnzIn + tStepSize*(-kF   * cEnzIn * cSubIn +kCat * cESIn  +kR * cESIn);
cSubOut=cSubIn + tStepSize*(-kF   * cEnzIn * cSubIn +kR   * cESIn             );
cProOut=cProIn + tStepSize*(+kCat * cESIn                                     );
cESOut =cESIn  + tStepSize*(+kF   * cEnzIn * cSubIn -kCat * cESIn  -kR * cESIn);



if (cEnzOut/cEnzIn<(1/exitConstant) || exitConstant<cEnzOut/cEnzIn...
        || cSubOut/cSubIn<(1/exitConstant) || exitConstant<cSubOut/cSubIn...
        || cProOut<0 || cESOut<0) && recursiveNumber<exitRecNumber
    cOutputRecursive=lacmodel(cInput,kF,kR,kCat,tStepSize/2,recursiveNumber);
    cOutput=lacmodel(cOutputRecursive,kF,kR,kCat,tStepSize/2,recursiveNumber);
else 
    cOutput=[cEnzOut, cProOut,cSubOut,cESOut];
end

return
    
end


