function [param,fitinfo] = MMSimfit(tdata,ydata,startp,endp,enzconc,fitinfo)

    global SimFun;    
    
    if fitinfo.flags.dt_s && fitinfo.flags.s0_s
        m0=[max(ydata(startp:endp)) fitinfo.kf_s fitinfo.kr_s...
            fitinfo.kcat_s round(-tdata(startp))];
    elseif fitinfo.flags.dt_s && ~fitinfo.flags.s0_s
        m0=[fitinfo.s0_s fitinfo.kf_s fitinfo.kr_s fitinfo.kcat_s...
            round(-tdata(startp))];
    elseif ~fitinfo.flags.dt_s && fitinfo.flags.s0_s
        m0=[max(ydata(startp:endp)) fitinfo.kf_s fitinfo.kr_s...
            fitinfo.kcat_s fitinfo.dt_s];
    elseif ~fitinfo.flags.dt_s && ~fitinfo.flags.s0_s 
        m0=[fitinfo.s0_s fitinfo.kf_s fitinfo.kr_s fitinfo.kcat_s...
            fitinfo.dt_s];
    end
    
    mup = [3000 100 10 2000 Inf];
    mlo = [0 0 0 0 -Inf];
    
    if fitinfo.flags.expleak
        SimFun  = @MMSimExpFit;
        m0      = [m0 fitinfo.kl];
        mlo     = [mlo 0];
        mup     = [mup Inf];
    elseif fitinfo.flags.linleak
        SimFun  = @MMSimLinFit;
        m0      = [m0 fitinfo.l];
        mlo     = [mlo 0];
        mup     = [mup Inf];
    else
        SimFun  = @MMSimNolFit;
    end
    
    fitinfo.formula     = func2str(SimFun);
    fitinfo.start_param = ['[',sprintf('%d,',m0(1:end-1)),sprintf('%d]',...
        m0(end))];
    fitinfo.lower_limit =['[',sprintf('%d,',mlo(1:end-1)),sprintf('%d]',...
        mlo(end))];
    fitinfo.upper_limit =['[',sprintf('%d,',mup(1:end-1)),sprintf('%d]',...
        mup(end))];
    
    v_TolX          = 10^-9;
    v_TolFun        = 10^-8;
    v_MaxFunEvals   = 1000;
    v_MaxIter       = 10000;
    
    fitinfo.TolX        = v_TolX;
    fitinfo.TolFun      = v_TolFun;
    fitinfo.MaxFunEvals = v_MaxFunEvals;
    fitinfo.MaxIter     = v_MaxIter;
   
    fitoptions=optimoptions('lsqcurvefit','Algorithm',fitinfo.fitmethod,...
        'TolX',v_TolX,'TolFun',v_TolFun,'MaxIter',v_MaxIter,...
        'MaxFunEvals',v_MaxFunEvals,'Display','off','PlotFcns',@optimplotfval);
    
    if strcmp(fitinfo.fitmethod,'trust-region-reflective')
        [param,resnorm,~,exitflag,~] = lsqcurvefit(...
        @(m,tdata) SimFun(m,tdata,enzconc),m0,tdata(startp:endp)...
        ,ydata(startp:endp),mlo,mup,fitoptions);
    else
        [param,resnorm,~,exitflag,~] = lsqcurvefit(...
        @(m,tdata) SimFun(m,tdata,enzconc),m0,tdata(startp:endp)...
        ,ydata(startp:endp),[],[],fitoptions);
    end
    
    
    fitinfo.flags.exitflag=exitflag;
    if size(param,1)>1
        param=param';
    end
    
    % Add the Enzyme Concentration at the start 
    param=[enzconc,param,resnorm];
    
    % Call MMAfterfit -> Plotting
    fitinfo=MMAfterfit(tdata,ydata,param,fitinfo);
    
end
